Tutorials
=========

This is a set of tutorials intended to follow complete tasks that interconnect several modules and classes to achieve
a given objective.

.. toctree::

    tutorial.cookbook
    tutorial.ljclusters
    tutorial.structural_search
    tutorial.euler_angles
    tutorial.magnetic_moments
    tutorial.orbitaldftu
